<?php

namespace Drupal\layout_builder_ipe\Form;

use Drupal\Core\Cache\Cache;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides the layout builder ipe configuration form.
 */
class LayoutBuilderIpeSettingsForm extends ConfigFormBase {

  /**
   * The cache factory.
   *
   * @var \Drupal\Core\Cache\CacheFactoryInterface
   */
  protected $cacheFactory;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    $instance = parent::create($container);
    $instance->cacheFactory = $container->get('cache_factory');
    return $instance;
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'layout_builder_ipe_settings';
  }

  /**
   * {@inheritdoc}
   */
  public function getEditableConfigNames() {
    return ['layout_builder_ipe.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->configFactory->get('layout_builder_ipe.settings');
    $form['disable_layout_page'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Disable the "Layout" page when using IPE'),
      '#default_value' => $config->get('disable_layout_page'),
      '#description' => $this->t('Disable the "Layout" page and the corresponding local task on entity pages where Layout Builder IPE is active.'),
    ];
    $form['hide_local_tasks_block'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Hide the local task block while editing'),
      '#default_value' => $config->get('hide_local_tasks_block'),
      '#description' => $this->t('Hide the local task block while editing a page.'),
    ];
    $form['enhance_ui'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Enhance the default Layout Builder UI'),
      '#default_value' => $config->get('enhance_ui'),
      '#description' => $this->t('Experimental: If enabled, the UI for adding new blocks to sections will be made more flexible, allowing to specifically place new blocks in between existing ones.'),
    ];
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config('layout_builder_ipe.settings')
      ->set('disable_layout_page', $form_state->getValue('disable_layout_page'))
      ->set('hide_local_tasks_block', $form_state->getValue('hide_local_tasks_block'))
      ->set('enhance_ui', $form_state->getValue('enhance_ui'))
      ->save();
    Cache::invalidateTags(['local_task']);
    $this->cacheFactory->get('render')->invalidateAll();
    parent::submitForm($form, $form_state);
  }

}
